netSEM-package: netSEM: Network Structural Equation Modeling

netSEM-packageR Documentation

netSEM: Network Structural Equation Modeling

Description

The network structural equation modeling conducts a network statistical analysis on a data frame of coincident observations of multiple continuous variables [1]. It builds a pathway model by exploring a pool of domain knowledge guided candidate statistical relationships between each of the variable pairs, selecting the 'best fit' on the basis of a specific criteria such as adjusted r-squared value. This material is based upon work supported by the U.S. National Science Foundation Award EEC-2052776 and EEC-2052662 for the MDS-Rely IUCRC Center, under the NSF Solicitation: NSF 20-570 Industry-University Cooperative Research Centers Program [1] Bruckman, Laura S., Nicholas R. Wheeler, Junheng Ma, Ethan Wang, Carl K. Wang, Ivan Chou, Jiayang Sun, and Roger H. French. (2013) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1109/ACCESS.2013.2267611")}.

Author(s)

Maintainer: Laura S. Bruckman lsh41@case.edu (ORCID)

Authors:

Other contributors:


netSEM documentation built on Feb. 25, 2026, 5:08 p.m.