netSEMp1: network Structural Equation Modeling (netSEM)

View source: R/netSEMp1.R

netSEMp1R Documentation

network Structural Equation Modeling (netSEM)

Description

This function carries out netSEM using markovian principle.

Usage

netSEMp1(x, exogenous, endogenous)

Arguments

x

A dataframe. By default it considers all columns as exogenous variables, except the first column which stores the system's endogenous variable.

exogenous

by default it considers all columns as exogenous variables except column number 1, which is the main endogenous response.

endogenous

A character string of the column name of the main endogenous OR a numeric number indexing the column of the main endogenous.

Details

netSEMp1 determines the univariate relationships in the spirit of the Markovian process and builds a network model. In this case, the relationship between each pair of system variables, including predictors and the system level response is determined with the Markovian property that assumes the value of the current predictor is sufficient in relating to the next level variable, i.e., the relationship is independent of the specific value of the preceding-level variable to the current predictor, given the current value. Each pair of variables is tested for sensible (in the domain knowledge sense) paring relation chosen from pre-selected common functional forms in linear regression settings. Adjusted R-squared is used for model selection for every pair.

P-values reported in the "res.print" field of the return list contains the P-values of estimators of linear regression coefficients. The P-values are ordered in the common order of coefficients, i.e. in the order of increasing exponents. For example, in the quadratic functional form y \sim b_0 + b_1 x + b_2 x^2, the three P-values correspond to those of \hat{b}_0, \hat{b}_1 and \hat{b}_2, respectively. If there are less than 3 coefficients to estimate, the extra P-value field is filled with NA's.

Value

An object of class netSEM, which is a list of the following items:

  • "data": data frame used in netSEMp1 analysis.

  • "exogenous": Main stressor variable.

  • "endogenous": Main response variable.

  • "bestModels": A dataframe.

  • "allModels": A list of model objects.

Examples

## Not run: 
## Load the sample acrylic data set
data(acrylic)

## Run netSEM_markovian
ans <- netSEMp1(acrylic, "IrradTot", "YI")

## End(Not run)

netSEM documentation built on Feb. 25, 2026, 5:08 p.m.