plot.netSEMp2: Plotting of netSEM diagram

View source: R/plot.netSEMp2.R

plot.netSEMp2R Documentation

Plotting of netSEM diagram

Description

Plot netSEMp2 result plot.netSEMp2 plots a structural equation network model diagram, fitted under principle 2, based on best functional form for each selected pairwise variable.

Usage

## S3 method for class 'netSEMp2'
plot(
  x,
  cutoff = NULL,
  latent = NULL,
  title = "netSEMp2",
  plot.save = FALSE,
  filename = NULL,
  style = TRUE,
  ...
)

Arguments

x

An object of class "netSEMp2", the returned list from netSEMp2.

cutoff

A threshold value for adjusted R-squared. The maximum number of cutoff is 3.

latent

The latent variable that corresponds to the mechanic variable. The default is NULL.

title

The title of the plot. Default value is "netSEMp2".

plot.save

True/False, it saves the network diagram plot as png file. The default is false.

filename

A character string naming a file to save as a png file.

style

True/False, it plots the first interval in the network diagram with dotted weak line. The default is True.

...

A S3 generic/method consistency.

Value

An html style plot of pairwise relationship pathway diagram between exogenous variables and an endogenous variable. Arrows show relationships between each variable with given statistical relations along the connection lines.

See Also

netSEMp2

Examples

## Not run: 
# Load acrylic data set
data(acrylic)

# Build a netSEMp2 model
ans <- netSEMp2(acrylic, "IrradTot", "YI")

# Plot the network model with a title
plot(ans, cutoff = c(0.3,0.6,0.8), title = "Acrylic")

\donttest{
# plot the network diagram and save file
plot(ans, cutoff = c(0.3,0.6,0.8), 
     plot.save = TRUE, 
     filename = "acrylic-netSEMp2")
}

## End(Not run)

netSEM documentation built on Feb. 25, 2026, 5:08 p.m.