var_selection: network Structural Equation Modeling (netSEM)

View source: R/var_selection.R

var_selectionR Documentation

network Structural Equation Modeling (netSEM)

Description

This function selects the variable that best represents a specific degradation mechanism with the greatest adjusted R^2 of <S|M|.

Usage

var_selection(a, exogenous, endogenous)

Arguments

a

A dataframe. By default it considers all columns as exogenous variables, except the first column which stores the system's endogenous variable.

exogenous

by default it considers all columns as exogenous variables except column number 1, which is the main endogenous response.

endogenous

A character string of the column name of the main endogenous OR a numeric number indexing the column of the main endogenous.

Value

A character string of the variable that best represents a specific degradation mechanism.

Examples

## Not run: 
## Load the sample acrylic data set
data(acrylic)

## Run netSEMp1_predict
ans <- var_selection(a = acrylic, exogenous = "IrradTot", endogenous = "YI")

## End(Not run)

netSEM documentation built on Feb. 25, 2026, 5:08 p.m.