| netSEM-package | R Documentation |
The network structural equation modeling conducts a network statistical analysis on a data frame of coincident observations of multiple continuous variables [1]. It builds a pathway model by exploring a pool of domain knowledge guided candidate statistical relationships between each of the variable pairs, selecting the 'best fit' on the basis of a specific criteria such as adjusted r-squared value. This material is based upon work supported by the U.S. National Science Foundation Award EEC-2052776 and EEC-2052662 for the MDS-Rely IUCRC Center, under the NSF Solicitation: NSF 20-570 Industry-University Cooperative Research Centers Program [1] Bruckman, Laura S., Nicholas R. Wheeler, Junheng Ma, Ethan Wang, Carl K. Wang, Ivan Chou, Jiayang Sun, and Roger H. French. (2013) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1109/ACCESS.2013.2267611")}.
Maintainer: Laura S. Bruckman lsh41@case.edu (ORCID)
Authors:
Wei-Heng Huang wxh272@case.edu (ORCID)
Nicholas R. Wheeler nrw16@case.edu (ORCID)
Addison G. Klinke agk38@case.edu (ORCID)
Yifan Xu yxx218@case.edu (ORCID)
Wenyu Du wxd97@case.edu (ORCID)
Amit K. Verma aak126@case.edu (ORCID)
Abdulkerim Gok axg515@case.edu (ORCID)
Roger H. French rxf131@case.edu (ORCID) [copyright holder]
Other contributors:
Devin A. Gordon dag109@case.edu (ORCID) [contributor]
Yu Wang yxw880@case.edu (ORCID) [contributor]
Sameera Nalin Venkat sxn440@case.edu (ORCID) [contributor]
HeinHtet Aung hxh483@case.edu (ORCID) [contributor]
Yeajin Jo yxj414@case.edu (ORCID) [contributor]
Xuanji Yu xxy530@case.edu (ORCID) [contributor]
Kemal Ozdemirli kxo146@case.edu [contributor]
Van D. Tran vxt101@case.edu (ORCID) [contributor]
Jonathan Gordon jgordon5@bowdoin.edu (ORCID) [contributor]
Jayvic Cristian Jimenez jxj440@case.edu (ORCID) [contributor]
Jiqi Liu jxl1763@case.edu (ORCID) [contributor]
Alan J. Curran ajc269@case.edu (ORCID) [contributor]
Justin S. Fada jsf77@case.edu (ORCID) [contributor]
Xuan Ma xxm115@case.edu (ORCID) [contributor]
Jennifer L. Braid jlb269@case.edu (ORCID) [contributor]
Jennifer L. W. Carter jwc137@case.edu (ORCID) [contributor]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.