View source: R/var_selection.R
| var_selection | R Documentation |
This function selects the variable that best represents a specific degradation mechanism with the greatest adjusted R^2 of <S|M|.
var_selection(a, exogenous, endogenous)
a |
A dataframe. By default it considers all columns as exogenous variables, except the first column which stores the system's endogenous variable. |
exogenous |
by default it considers all columns as exogenous variables except column number 1, which is the main endogenous response. |
endogenous |
A character string of the column name of the main endogenous OR a numeric number indexing the column of the main endogenous. |
A character string of the variable that best represents a specific degradation mechanism.
## Not run:
## Load the sample acrylic data set
data(acrylic)
## Run netSEMp1_predict
ans <- var_selection(a = acrylic, exogenous = "IrradTot", endogenous = "YI")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.